componenttools.cut_component_at_prolated_duration
=================================================

.. autofunction:: abjad.tools.componenttools.cut_component_at_prolated_duration.cut_component_at_prolated_duration
